Description Value Slots Examples
S4 class for storing circRNA relevant information.
circSample-object
sample.idThe id of the sample, specified by the input sample file naming (e.g. 'aligned/[sample]/Chimeric.out.junction', where '[sample]' are the applied id.), 'sample.id“. Must be unique!
organismThe organism of which the smaple originates from.
gbThe specific genome build used for alining the sample.
chim.fileFile location for the sample 'Chimeric.out.junction' alignment output.
bam.fileFile locaion for the sample 'Aligned.X.out.bam' alignment output, where X specifies a sorting option during alignment by the STAR algorithm. #[PROPPER REFS?]
log.fileFile location for the sample 'Log.final.out' alignment run log.
sj.fileFile location for the sample 'SJ.out.tab' alignment output.
firstread.firststrandLibrary preparation protocol, relative to library strandedness. If a first_read-first_strand protocol is used (e.g. dUTP), then 'firstread.firststrand' is 'TRUE', if first_read-second_strand or unstranded then it is 'FALSE'.
paired.endFlag used for describing if whether the sample sequnecing data are paired-end or single-end. Must be logical!
bsj.readsAnnotated and shifted candidate junctions
bsj.countsThe number of reads covering a backsplice junction for each detected basckplice junction CANDIDATES?.
lsj.countsThe input linear splice junction data.
labelAn optional name for a given sample, if no 'label' is provided, 'sample.id“ will be used. Need to check if labels are unique when constructing an experiment!!!!
1 2 3 4 5 6 7 8 9 10 11 | circSample(
sample.id = "A549",
organism = "Homo sapiens",
gb = "hg38",
chim.file = "Chimeric.out.junction",
bam.file = "Aligned.sortedByCoord.out.bam",
log.file = "Log.final.out",
sj.file = "SJ.out.tab",
firstread.firststrand = TRUE,
paired.end = TRUE
)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.