log.file-set: Replacement method for the STAR alignment Log file path

Description Usage Arguments Value Examples

Description

circSample class replacement methods for replacing the STAR alignment Log file path The replacment value must be valid to enable replacement

Usage

1
log.file(object) <- value

Arguments

object

circSample bject

Value

New class object with replaced STAR alignment Log file path

Examples

1
2
# Replacing STAR alignment Log file path of a sample object
#log.file(sample.object) <- new.path

KasperThystrup/circulaR documentation built on March 14, 2021, 12:44 p.m.