lsj.counts: Accessor for summarized data on linear splice sites

Description Usage Arguments Value Examples

Description

circSample and circExperiment class accessors for showing the linear splice junction count data

Usage

1
lsj.counts(object)

Arguments

object

circSample or circExperiment object

Value

Datatable(s) of linear splice junction count data

Examples

1
2
3
4
5
# A datatable of the linear splice junction count data in a sample object
#lsj.counts(sample.object)

# A datatable of the linear splice junction count data in each sample of an experiment
#lsj.counts(experiment.object)

KasperThystrup/circulaR documentation built on March 14, 2021, 12:44 p.m.