mle.vonmises(x, mu=NULL, kappa=NULL, bias=FALSE, control.circular=list())
## S3 method for class 'mle.vonmises':
print(x,
digits = max(3, getOption("digits") - 3), ...)circular.NULL the maximum likelihood estimate of the mean
direction is calculated. If provided it is coerced to a class circular.NULL the maximum likelihood estimate of the
concentration parameter is calculated.TRUE, the estimate for kappa is
computed with a bias corrected method. Default is FALSE,
i.e. no bias correction.mu)circular.mu.Best, D. and Fisher N. (1981). The bias of the maximum likelihood estimators of the von Mises-Fisher concentration parameters. Communications in Statistics - Simulation and Computation, B10(5), 493-502.
mean.circular and mle.vonmises.bootstrap.cix <- rvonmises(n=50, mu=circular(0), kappa=5)
mle.vonmises(x) # estimation of mu and kappa
mle.vonmises(x, mu=circular(0)) # estimation of kappa onlyRun the code above in your browser using DataLab