readLSJdata: Read the data on reads spanning linear splice junctions

Description Usage Arguments Value Examples

Description

The function takes a circSample or circExperiment object and reads the chimeric data for samples described in these objects (SJ.out.tab file).

Usage

1
readLSJdata(object, chromosomes = c(1:22, "X", "Y"), cores = 1L, ...)

Arguments

object

circSample or circExperiment object

chromosomes

A vector of (valid) chromosome names that is used to restrict the chimeric read data

cores

Only supported on unix! Number of cores used for parallel processing for circExperiment objets.

Value

Same as input object, but populated slot for lsj counts.

Examples

1
#readLSJdata(object)

KasperThystrup/circulaR documentation built on March 14, 2021, 12:44 p.m.