Description Usage Arguments Value Examples
circSample and circExperiment class accessors for showing the linear splice junction count data
1 | lsj.counts(object)
|
object |
circSample or circExperiment object |
Datatable(s) of linear splice junction count data
1 2 3 4 5 | # A datatable of the linear splice junction count data in a sample object
#lsj.counts(sample.object)
# A datatable of the linear splice junction count data in each sample of an experiment
#lsj.counts(experiment.object)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.