Description Usage Arguments Value Examples
The function takes a circSample or circExperiment object and reads the chimeric data for samples described in these objects (SJ.out.tab file).
1 | readLSJdata(object, chromosomes = c(1:22, "X", "Y"), cores = 1L, ...)
|
object |
circSample or circExperiment object |
chromosomes |
A vector of (valid) chromosome names that is used to restrict the chimeric read data |
cores |
Only supported on unix! Number of cores used for parallel processing for circExperiment objets. |
Same as input object, but populated slot for lsj counts.
1 | #readLSJdata(object)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.