- x
a vector, matrix or data.frame. The object is coerced to class circular.
- pch
point character to use. See help on par.
- cex
point character size. See help on par.
- axes
logical: if TRUE axes are plotted according to properties of x.
- shrink
parameter that controls the size of the plotted circle.
Default is 1. Larger values shrink the circle, while smaller values enlarge the circle.
- bins
number of arcs to partition the circle with.
- upper
therose diagram cells are "upper"-closed intervals.
- ticks
logical: if TRUE ticks are plotted according to the
value of bins.
- tcl
length of the ticks.
- tcl.text
the position of the axis labels.
- radii.scale
make possible to choose sector radius form:
square-root of relative frequency (sqrt, default) or
conventional linear scale (linear).
- border
the color to draw the border. The default, NULL, means to
use par("fg"). Use border = NA to omit borders.
- col
the color for filling the rose diagram. The default,
NULL, is to leave rose diagram unfilled.
color of the points. The values are recycled if needed.
- tol
proportion of white space at the margins of plot.
- uin
desired values for the units per inch parameter. If of length
1, the desired units per inch on the x axis.
- xlim, ylim
the ranges to be encompassed by the x and y
axes. Useful for centering the plot.
- prop
numerical constant determining the radii of the sectors. By default, prop = 1.
- digits
number of digits used to print axis values.
- plot.info
an object from plot.circular that
contains information on the zero, the rotation and next.points.
- units
the units used in the plot. If NULL the units of the first component of 'x' is used.
- template
the template of the plot. Ignored if plot.info is provided.
- zero
the zero of the plot. Ignored if plot.info or template are provided.
- rotation
the rotation of the plot. Ignored if plot.info or template are provided.
- main, sub, xlab, ylab
title, subtitle, x label and y label of the plot.
- add
add the rose diag to an existing plot.
- control.circle
parameters passed to plot.default in order to draw the circle. The function circle.control is used to set the parameters.
- ...
further parameters passed to polygon.